@@ -24,7 +24,7 @@ except ImportError as e:
     from filter import cigar
     from filter import qualities_cigar
 
-__version__ = '0.3.7'
+__version__ = '0.3.11'
 
 def downstream_phase_detection(variants, segment, record, quality):
     """
@@ -556,7 +556,7 @@ class Pair():
             tract for tract in self.condensed 
             if tract[0] == self.converted_haplotype][0][1:])
         if indels:
-            self.indel_proximity = abs(min(np.concatenate(
+            self.indel_proximity = min(abs(np.concatenate(
                 [np.array(indel[1:]) - np.array(conversion_tract)
                  for indel in indels])))
         else:
@@ -741,13 +741,13 @@ class Pair():
         # simplification of results
         # [(haplotype, beginning, end), ...]
 
-        if self.call == 'no_phase_change':
+        if self.masked_call == 'no_phase_change':
             # midpoint is middle of two paired reads if no phase change
             start = self.rec_1.reference_start
             end = self.rec_2.reference_start + len(self.segment_2)
             self.midpoint = int((start + end) / 2)
             self.relative_midpoint = -1
-        elif self.call == 'cross_over':
+        elif self.masked_call == 'cross_over':
             # (X, begin, end), (Y, begin, end): end of X = beginning of Y = midpoint
             self.midpoint = self.condensed[0][2]
             # get relative midpoint
@@ -755,12 +755,12 @@ class Pair():
             end = self.condensed[-1][2]
             self.relative_midpoint = round(
                 (self.midpoint - self.rec_1.reference_start) / (end - start), 3)
-        elif self.call == 'cross_over':
+        elif self.masked_call == 'gene_conversion':
             # (X, begin, end), (Y, begin, end), (X', begin, end)
             # midpoint of Y tract
             self.midpoint = sum([
                 [start, end] for hap, start, end in self.condensed
-                if hap == self.converted_haplotype][0]) / 2
+                if hap == self.converted_haplotype]) / 2
             start = self.condensed[0][1]
             end = self.condensed[-1][2]
             self.relative_midpoint = round(
