@@ -37,7 +37,7 @@ def arg_parser():
         usage='readcomb-fp [options]')
 
     parser.add_argument('-f', '--fname', required=True, type=str, 
-        help='Cross BAM output by readcomb-filter')
+        help='Cross SAM output by readcomb-filter')
     parser.add_argument('-fp', '--false_plus', required=False, type=str, 
         help='False positives from plus parent')
     parser.add_argument('-fm', '--false_minus', required=False, type=str, 
@@ -54,7 +54,7 @@ def arg_parser():
         help='Path to log file')
     parser.add_argument('-o', '--out', required=True, type=str,
         help='File to write filtered reads to')
-    parser.add_argument('--version', action='version', version='readcomb 0.3.7')
+    parser.add_argument('--version', action='version', version='readcomb 0.3.11')
 
     return parser
 
@@ -395,8 +395,17 @@ class FalsePositiveFilterer():
                 continue
             chrom = pair.rec_1.reference_name
             start, end = pair.detection[0][1], pair.detection[-1][1]
-            false_lookup = list(set([
-                line for line in self.tabix_reader.fetch(chrom, start, end)]))
+
+            # handle tabix issues if organelle/contig region iterator can't be made
+            try:
+                false_lookup = list(set([
+                    line for line in self.tabix_reader.fetch(chrom, start, end)]))
+            except ValueError as e:
+                if any(region in e.args[0] for region in ['cpDNA', 'mtDNA', 'contig']):
+                    false_lookup = []
+                else:
+                    raise e
+
             if not false_lookup: # no false phase changes at all
                 log_row['pairs_kept'] += 1 
                 self.writer.write(pair.rec_1)
@@ -479,6 +488,8 @@ def handle_bed(args):
         return tabix_reader
 
     # if not - generate lookup bed file
+    if args.false_bed_out.endswith('.gz'):
+        args.false_bed_out = args.false_bed_out.rstrip('.gz')
     bed_generator = BedGenerator(
         false_plus=args.false_plus, 
         false_minus=args.false_minus,
@@ -504,7 +515,7 @@ def main():
         out=args.out,
         log=args.log)
     filterer.filter_false_positives()
-    print(f'[rcmb] written to {args.out}')
+    print(f'[readcomb] written to {args.out}')
 
 
 if __name__ == '__main__':
